pub struct HttpStatement<'a> {
pub sequence: u8,
pub paths: Vec<Cow<'a, str>>,
pub methods: Vec<RapidRecastHttpMethod>,
pub actions: Vec<RapidRecastAction<'a>>,
}Expand description
Allows for specifying parts of an HTTP statement
Fields
sequence: u8Protocol sequence, where the order is determined from CLI order
ex. rapidrecast --http host1:123,host1:234,host2:345
That declares 3 protocols, so sequence=2 means binding host2:345
paths: Vec<Cow<'a, str>>The paths to match on the HTTP protocol
methods: Vec<RapidRecastHttpMethod>The methods of access for this rule. GET, POST, DELETE, UPDATE
actions: Vec<RapidRecastAction<'a>>Actions that take effect once the protocol is triggered